@@ -301,7 +301,7 @@ class Date_Holidays_Driver
      */
     function addTranslation($locale)
     {
-        $data_dir = "/usr/obj/ports/pear-Date-Holidays-0.21.7/fake-sparc64/var/www/pear/data";
+        $data_dir = "/usr/obj/ports/pear-Date-Holidays-0.21.8/fake-arm64/var/www/pear/data";
         $bestLocale = $this->_findBestLocale($locale);
         $matches = array();
         $loaded = false;
