@@ -1,9 +1,8 @@
 <?php
     function testHolidays2005stampsAndSavingsDay() {
         $drv = &Date_Holidays::factory('Germany', 2005);
-        $this->assertFalse(Date_Holidays::isError($drv));
         if (Date_Holidays::isError($drv)) {
-           die($drv->getMessage());
+           $this->fail(helper_get_error_message($drv));
         }
         $holidays = $drv->getHolidayForDate('2005-10-30', null, true);
         $this->assertEquals('savingsDay', $holidays[0]->getInternalName(), 'should be savingsDay');
